const fs = require('fs');
const { promisify } = require('util');
const existsAsync = promisify(fs.exists);
const readFileAsync = promisify(fs.readFile);

/**
 * Loads an icon file and returns it as a data URI.  Supports bmp, jpeg, jpg, png, gif,
 * tiff, and svg.
 * @param {string} file - The icon file to load.
 * @return {Promise<string>} The icon data URI.
 */
function loadIcon(file) {
	return existsAsync(file).then(exists => {
		if (!exists) {
			throw new Error(`File does not exist: ${file}`);
		}

		const match = file.match(/\.(?:bmp|jpeg|jpg|png|gif|tiff|svg)$/);
		if (!match) {
			throw new Error(`Not a valid icon file: ${file}`);
		}

		let type = match[0].substr(1);
		if (type === 'svg') {
			type = 'svg+xml';
		} else if (type === 'jpg') {
			type = 'jpeg';
		}

		return readFileAsync(file).then(bytes => {
			const data = bytes.toString('base64');
			return `data:image/${type};base64,${data}`;
		});
	});
}

exports = module.exports = loadIcon;
